@@ -3,6 +3,8 @@ use Moose;
 
 extends 'Chart::Clicker::Data::Series';
 
+use List::Util qw(min max);
+
 has 'sizes' => (
     traits => [ 'Array' ],
     is => 'rw',
@@ -15,6 +17,30 @@ has 'sizes' => (
     }
 );
 
+has max_size => (
+    is => 'ro',
+    isa => 'Num',
+    lazy_build => 1
+);
+
+has min_size => (
+    is => 'ro',
+    isa => 'Num',
+    lazy_build => 1
+);
+
+sub _build_max_size {
+    my ($self) = @_;
+
+    return max(@{ $self->sizes });
+}
+
+sub _build_min_size {
+    my ($self) = @_;
+
+    return min(@{ $self->sizes });
+}
+
 __PACKAGE__->meta->make_immutable;
 
 no Moose;
@@ -49,6 +75,14 @@ for the Bubble renderer.
 
 Set/Get the sizes for this series.
 
+=head2 max_size
+
+Gets the largest value from this Series' C<sizes>.
+
+=head2 min_size
+
+Gets the smallest value from this Series' C<sizes>.
+
 =head1 METHODS
 
 =head2 new
