@@ -185,7 +185,7 @@ values making the slices longer.  The 360 degrees of pie is divided equally.
 
 =begin HTML
 
-<p><img src="http://www.onemogin.com/clicker/chart-clicker-examples/polararea/polararea.png" width="500" height="250" alt="Pie Chart" /></p>
+<p><img src="http://www.onemogin.com/clicker/chart-clicker-examples/polararea/polararea.png" width="300" height="250" alt="Polar Area Chart" /></p>
 
 =end HTML
 
@@ -205,7 +205,8 @@ Set/Get the Color to use for the border.
 
 =head2 brush
 
-Set/Get a Brush to be used for the pie's border.
+Set/Get a Brush to be used for the polar area's borders, which are around
+each slice.
 
 =head1 METHODS
 
